PyXPad
======

Data visualisation and analysis tool in Python,
intended to be familiar to users of XPAD.

Primarily for IDAM data from the MAST tokamak experiment,
but can be used to view NetCDF files currently.

Ben Dudson, Department of Physics, University of York
Email: benjamin.dudson@york.ac.uk

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

Installation
------------

You can install PyXPad using pip:

    pip install PyXPad

You can install the latest version from GitHub:

    pip install git+https://github.com/ZedThree/pyxpad.git

Dependencies
------------

PyXPad requires matplotlib, numpy, scipy, Qt.py and xdg, as well as
either PyQt4, PyQt5 or PySide.
